==> hs-hint-0.3.2.1.tbz: lib/hint-0.3.2.1/register.sh <==
#!/bin/sh

echo 'name: hint
version: 0.3.2.1
license: BSD3
copyright:
maintainer: jcpetruzza@gmail.com
stability:
homepage: http://projects.haskell.org/hint
package-url:
description: This library defines an @Interpreter@ monad. It allows to load Haskell
             modules, browse them, type-check and evaluate strings with Haskell
             expressions and even coerce them into values. The library is
             thread-safe and type-safe (even the coercion of expressions to
             values).
             It is, esentially, a huge subset of the GHC API wrapped in a simpler
             API. Works with GHC 6.10.x and 6.8.x
             (this version was not tested with GHC 6.6).
category: Language, Compilers/Interpreters
author: Daniel Gorin
exposed: True
exposed-modules: Language.Haskell.Interpreter
                 Language.Haskell.Interpreter.Extension
                 Language.Haskell.Interpreter.Unsafe
                 Language.Haskell.Interpreter.GHC
                 Language.Haskell.Interpreter.GHC.Unsafe
hidden-modules: Hint.GHC Hint.Base Hint.InterpreterT Hint.Compat
                Hint.Configuration Hint.Extension Hint.Context Hint.Conversions
                Hint.Eval Hint.Parsers Hint.Reflection Hint.Typecheck Hint.Sandbox
                Hint.Util
import-dirs: /usr/local/lib/hint-0.3.2.1/ghc-6.10.4
library-dirs: /usr/local/lib/hint-0.3.2.1/ghc-6.10.4
hs-libraries: HShint-0.3.2.1
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: MonadCatchIO-mtl-0.2.0.0 base-4.1.0.0 directory-1.0.0.3
         extensible-exceptions-0.1.1.0 filepath-1.1.0.2 ghc-6.10.4
         ghc-mtl-1.0.1.0 ghc-paths-0.1.0.5 haskell-src-1.0.1.3 mtl-1.1.0.2
         random-1.0.0.1 utf8-string-0.3.6
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hint-0.3.2.1/html/hint.haddock
haddock-html: /usr/local/share/doc/hint-0.3.2.1/html' | /usr/local/bin/ghc-pkg update -

==> hs-hint-0.3.2.3.tbz: lib/hint-0.3.2.3/register.sh <==
#!/bin/sh

echo 'name: hint
version: 0.3.2.3
license: BSD3
copyright:
maintainer: jcpetruzza@gmail.com
stability:
homepage: http://projects.haskell.org/hint
package-url:
description: This library defines an @Interpreter@ monad. It allows to load Haskell
             modules, browse them, type-check and evaluate strings with Haskell
             expressions and even coerce them into values. The library is
             thread-safe and type-safe (even the coercion of expressions to
             values).
             It is, esentially, a huge subset of the GHC API wrapped in a simpler
             API. Works with GHC 6.10.x and 6.8.x
             (this version was not tested with GHC 6.6).
category: Language, Compilers/Interpreters
author: Daniel Gorin
exposed: True
exposed-modules: Language.Haskell.Interpreter
                 Language.Haskell.Interpreter.Extension
                 Language.Haskell.Interpreter.Unsafe
                 Language.Haskell.Interpreter.GHC
                 Language.Haskell.Interpreter.GHC.Unsafe
hidden-modules: Hint.GHC Hint.Base Hint.InterpreterT Hint.Compat
                Hint.Configuration Hint.Extension Hint.Context Hint.Conversions
                Hint.Eval Hint.Parsers Hint.Reflection Hint.Typecheck Hint.Sandbox
                Hint.Util
import-dirs: /usr/local/lib/hint-0.3.2.3/ghc-6.10.4
library-dirs: /usr/local/lib/hint-0.3.2.3/ghc-6.10.4 /usr/local/lib
hs-libraries: HShint-0.3.2.3
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: MonadCatchIO-mtl-0.3.0.1 base-4.1.0.0 directory-1.0.0.3
         extensible-exceptions-0.1.1.0 filepath-1.1.0.2 ghc-6.10.4
         ghc-mtl-1.0.1.0 ghc-paths-0.1.0.5 haskell-src-1.0.1.3 mtl-1.1.0.2
         random-1.0.0.1 utf8-string-0.3.6
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hint-0.3.2.3/html/hint.haddock
haddock-html: /usr/local/share/doc/hint-0.3.2.3/html' | /usr/local/bin/ghc-pkg update -
